==> h2o-java-rest-bindings-3.8.2.8-sources.jar: water/bindings/pojos/GrepModelOutputV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
import java.util.Map;


public class GrepModelOutputV3 extends ModelOutputSchema {
    /** Matching strings */
    public String[] matches;

    /** Byte offsets of matches */
    public long[] offsets;

    /* INHERITED: Column names 
    public String[] names = null;
     */

    /* INHERITED: Domains for categorical columns 
    public String[][] domains = null;
     */

    /* INHERITED: Cross-validation models (model ids) 
    public ModelKeyV3[] cross_validation_models = null;
     */

    /* INHERITED: Cross-validation predictions, one per cv model (deprecated, use cross_validation_holdout_predictions_frame_id instead) 
    public FrameKeyV3[] cross_validation_predictions = null;
     */

    /* INHERITED: Cross-validation holdout predictions (full out-of-sample predictions on training data) 
    public FrameKeyV3 cross_validation_holdout_predictions_frame_id = null;
     */

    /* INHERITED: Cross-validation fold assignment (each row is assigned to one holdout fold) 
    public FrameKeyV3 cross_validation_fold_assignment_frame_id = null;
     */

    /* INHERITED: Category of the model (e.g., Binomial) 
    public ModelCategory model_category = null;
     */

    /* INHERITED: Model summary 
    public TwoDimTableV3 model_summary = null;
     */

    /* INHERITED: Scoring history 
    public TwoDimTableV3 scoring_history = null;
     */

    /* INHERITED: Training data model metrics 
    public ModelMetricsBase training_metrics = null;
     */

    /* INHERITED: Validation data model metrics 
    public ModelMetricsBase validation_metrics = null;
     */

    /* INHERITED: Cross-validation model metrics 
    public ModelMetricsBase cross_validation_metrics = null;
     */

    /* INHERITED: Cross-validation model metrics summary 
    public TwoDimTableV3 cross_validation_metrics_summary = null;
     */

    /* INHERITED: Job status 
    public String status = "";
     */

    /* INHERITED: Start time in milliseconds 
    public long start_time = 0L;
     */

    /* INHERITED: End time in milliseconds 
    public long end_time = 0L;
     */

    /* INHERITED: Runtime in milliseconds 
    public long run_time = 0L;
     */

    /* INHERITED: Help information for output fields 
    public Map<String,String> help = null;
     */

    public GrepModelOutputV3() {
        matches = null;
        offsets = null;
        names = null;
        domains = null;
        cross_validation_models = null;
        cross_validation_predictions = null;
        cross_validation_holdout_predictions_frame_id = null;
        cross_validation_fold_assignment_frame_id = null;
        model_category = null;
        model_summary = null;
        scoring_history = null;
        training_metrics = null;
        validation_metrics = null;
        cross_validation_metrics = null;
        cross_validation_metrics_summary = null;
        status = "";
        start_time = 0L;
        end_time = 0L;
        run_time = 0L;
        help = null;
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.11-sources.jar: water/bindings/pojos/GrepModelOutputV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
import java.util.Map;

public class GrepModelOutputV3 extends ModelOutputSchema {
    /** Matching strings */
    public String[] matches;

    /** Byte offsets of matches */
    public long[] offsets;

    /* INHERITED: Column names 
     * public String[] names;
     */

    /* INHERITED: Domains for categorical columns 
     * public String[][] domains;
     */

    /* INHERITED: Cross-validation models (model ids) 
     * public ModelKeyV3[] cross_validation_models;
     */

    /* INHERITED: Cross-validation predictions, one per cv model (deprecated, use cross_validation_holdout_predictions_frame_id instead) 
     * public FrameKeyV3[] cross_validation_predictions;
     */

    /* INHERITED: Cross-validation holdout predictions (full out-of-sample predictions on training data) 
     * public FrameKeyV3 cross_validation_holdout_predictions_frame_id;
     */

    /* INHERITED: Cross-validation fold assignment (each row is assigned to one holdout fold) 
     * public FrameKeyV3 cross_validation_fold_assignment_frame_id;
     */

    /* INHERITED: Category of the model (e.g., Binomial) 
     * public ModelCategory model_category;
     */

    /* INHERITED: Model summary 
     * public TwoDimTableV3 model_summary;
     */

    /* INHERITED: Scoring history 
     * public TwoDimTableV3 scoring_history;
     */

    /* INHERITED: Training data model metrics 
     * public ModelMetricsBase training_metrics;
     */

    /* INHERITED: Validation data model metrics 
     * public ModelMetricsBase validation_metrics;
     */

    /* INHERITED: Cross-validation model metrics 
     * public ModelMetricsBase cross_validation_metrics;
     */

    /* INHERITED: Cross-validation model metrics summary 
     * public TwoDimTableV3 cross_validation_metrics_summary;
     */

    /* INHERITED: Job status 
     * public String status;
     */

    /* INHERITED: Start time in milliseconds 
     * public long start_time;
     */

    /* INHERITED: End time in milliseconds 
     * public long end_time;
     */

    /* INHERITED: Runtime in milliseconds 
     * public long run_time;
     */

    /* INHERITED: Help information for output fields 
     * public Map<String,String> help;
     */

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
